from main import Main
from vitamin import Vitamin
from mineral import Mineral
from other import Other

__version__ = "1.0.4"
__sources__ = [
    "https://www.fda.gov/files/food/published/Food-Labeling-Guide-%28PDF%29.pdf",
    "https://www.usdairy.com/~/media/usd/public/dmi-quick-reference-guide_nutrition-claims-for-dairy-products_2018.pdf",
]
